leaftools.expr_has_leaf_with_dotted_written_duration
====================================================

.. autofunction:: abjad.tools.leaftools.expr_has_leaf_with_dotted_written_duration.expr_has_leaf_with_dotted_written_duration
